unit TernarySeries;

interface

uses
  Winapi.Windows, Winapi.Messages, System.SysUtils, System.Variants, System.Classes, Vcl.Graphics,
  Vcl.Controls, Vcl.Forms, Vcl.Dialogs, VclTee.TeeGDIPlus, Vcl.ExtCtrls,
  VCLTee.TeEngine, VCLTee.TeeSurfa, VCLTee.TeeTernary, Vcl.StdCtrls,
  VCLTee.TeeProcs, VCLTee.Chart, VCLTee.TeeURL, VCLTee.TeeSeriesTextEd, Data.DB,
  DBTables, Data.Win.ADODB, VCLTee.Series, VCLTee.DBChart;

type
  TTernarySeriesForm = class(TForm)
    Button1: TButton;
    Panel1: TPanel;
    SeriesTextSource1: TSeriesTextSource;
    Chart1: TDBChart;
    Button2: TButton;
    procedure Button1Click(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure Chart1BeforeDrawAxes(Sender: TObject);
    procedure Button2Click(Sender: TObject);
    procedure Chart1AfterDraw(Sender: TObject);
  private
    { Private declarations }
    function SeriesGetPointerStyle(Sender: TChartSeries; ValueIndex: Integer): TSeriesPointerStyle;
    procedure SeriesAfterAdd(Sender: TChartSeries; ValueIndex: Integer);
    procedure BeforeDrawFirst(Sender: TObject);
    procedure BeforeDrawSecond(Sender: TObject);
  public
    { Public declarations }
  end;

var
  TernarySeriesForm: TTernarySeriesForm;
  kbmMemTable1: TTable;

implementation

{$R *.dfm}

Uses EditChar, TeeConst, TeeTernaryEdit;

procedure TTernarySeriesForm.Button1Click(Sender: TObject);
begin
  EditSeries(Self,Chart1[0]);
end;

procedure TTernarySeriesForm.Button2Click(Sender: TObject);
var wIndex: Integer;
begin
  wIndex:=0;
  while (wIndex<SeriesTextSource1.Fields.Count) and (SeriesTextSource1.Fields[wIndex].FieldName <> 'Weighting') do
    Inc(wIndex);

  if wIndex<SeriesTextSource1.Fields.Count then
  begin
    if (SeriesTextSource1.Fields[wIndex].FieldIndex = 7) then
      SeriesTextSource1.Fields[wIndex].FieldIndex:=6
    else
      SeriesTextSource1.Fields[wIndex].FieldIndex:=7;
  end;

  SeriesTextSource1.Active:=True;
  Chart1[0].CheckDataSource;
end;

procedure TTernarySeriesForm.Chart1AfterDraw(Sender: TObject);
var i, j: Integer;
begin
  for i:=0 to 2 do
  with TTernarySeries(Chart1[i]) do
  begin
    Chart1.Canvas.MoveTo(CalcXPos(0), CalcYPos(0));
    for j:=1 to Count-1 do
    begin
      Chart1.Canvas.LineTo(CalcXPos(j), CalcYPos(j));
    end;
  end;
end;

procedure TTernarySeriesForm.Chart1BeforeDrawAxes(Sender: TObject);
begin
//  Chart1.Legend.Title.Visible := Series1.ColorEachPoint;
  Chart1.Legend.Title.Visible := True;
end;

procedure TTernarySeriesForm.FormCreate(Sender: TObject);
var
  z: boolean;
  Lkbm: TTable;
  af: TFieldDefs;
  i, t: integer;
  LADO: TADOQuery;
  aDataset1, aDataset2, aDataset3: TDataset;
begin
  inherited;

  FormatSettings.DecimalSeparator:='.';

  for i:=0 to 2 do
  begin
    with TTernarySeries(Chart1.AddSeries(TTernarySeries)) do
    begin
      case i of
        0: begin
             Title:='AT-303';
             Pointer.Style:=psDonut;
           end;

        1: begin
             Title:='AT-505';
             Pointer.Style:=psTriangle;
           end;
        2: begin
             Title:='AT-602';
             Pointer.Style:=psDownTriangle;
           end;
      end;

      if i>0 then
      begin
        VertexTitle.Hide;
        Chart1.Axes.Hide;
        BeforeDrawValues:=BeforeDrawSecond;
      end
      else
        BeforeDrawValues:=BeforeDrawFirst;

      OnAfterAdd:=SeriesAfterAdd;
      DataSource := SeriesTextSource1;

      with SeriesTextSource1 do
      begin
        HeaderLines:=1;
        FileName := 'Na-Mg-K.csv';
        FieldSeparator:=',';
        Fields.Clear;

        AddField('X',3);
        AddField('Y',4);
        AddField('Z',5);
        AddField('Radius',6);
        AddField('Weighting',7);
        AddField('Text',8);

        Load;
      end;

      UseColorRange:=true;
      VertexTitles[0][0] := 'Na/1000' ;
      VertexTitles[1][0] := 'Sqrt(Mg)' ;
      VertexTitles[2][0] := 'K/100' ;

      //TernaryStyle:=tsBubble;
      Pointer.Transparency:=50;
      ShowInLegend:=False;

      UseColorRange:=False;

      OnGetPointerStyle:=SeriesGetPointerStyle;
    end;
  end;

  for i:=0 to 2 do
  begin
    with TPointSeries(Chart1.AddSeries(TPointSeries)) do
    begin
      Title:=Chart1[i].Title;
      Pointer.Style:=TTernarySeries(Chart1[i]).Pointer.Style;
    end;
  end;

  //Chart1.Legend.TextStyle := ltsPlain;
  //Chart1.Legend.Title.Text.Add('Sample Site  Sample Date');
  Chart1.Legend.Title.TextAlignment := taLeftJustify;
  Chart1.Legend.Width :=30;
  Chart1.Legend.Title.Visible:=true;
  Chart1.Walls.Back.Hide;
end;

type TTernarySeriesAccess=class(TTernarySeries);

function TTernarySeriesForm.SeriesGetPointerStyle(Sender: TChartSeries; ValueIndex: Integer): TSeriesPointerStyle;
begin
  TTernarySeriesAccess(Sender).PreparePointer(ValueIndex);
  result:=TTernarySeries(Sender).Pointer.Style;
end;

procedure TTernarySeriesForm.SeriesAfterAdd(Sender: TChartSeries; ValueIndex: Integer);
begin
  if (AnsiPos(Sender.Title, Sender.Labels[ValueIndex]) = 0) then
     Sender.Delete(ValueIndex);
end;

procedure TTernarySeriesForm.BeforeDrawFirst(Sender: TObject);
begin
  Chart1.Axes.Visible:=True;
end;

procedure TTernarySeriesForm.BeforeDrawSecond(Sender: TObject);
begin
  Chart1.Axes.Hide;
end;

end.
